@@ -1,12 +1,27 @@
-#define __GPA_PRINTER_C__
+#define __GPA_MEDIA_C__
 
-/*                                                            
- * Media tree methods
+/*
+ * This file is part of libgnomeprint 2
+ *
+ * Libgnomeprint is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
+ *
+ * Libgnomeprint is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public
+ * License along with the libgnomeprint; see the file COPYING.LIB.  If not,
+ * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  *
  * Authors :
  *   Lauris Kaplinski <lauris@ximian.com>
  *
- * Copyright (C) 2000-2001 Ximian, Inc. and Jose M. Celorio
+ * Copyright (C) 2001 Ximian, Inc.
  *
  */
 
